==> aws-cdk-lib-2.51.1-sources.jar: software/amazon/awscdk/services/codedeploy/ILambdaDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * The Deployment Configuration of a Lambda Deployment Group.
 * <p>
 * If you're managing the Deployment Configuration alongside the rest of your CDK resources,
 * use the {&#64;link LambdaDeploymentConfig} class.
 * <p>
 * If you want to reference an already existing deployment configuration,
 * or one defined in a different CDK Stack,
 * use the {&#64;link LambdaDeploymentConfig#fromLambdaDeploymentConfigName} method.
 * <p>
 * The default, pre-defined Configurations are available as constants on the {&#64;link LambdaDeploymentConfig} class
 * (<code>LambdaDeploymentConfig.AllAtOnce</code>, <code>LambdaDeploymentConfig.Canary10Percent30Minutes</code>, etc.).
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.71.0 (build f1f58ae)", date = "2022-11-18T21:59:09.896Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.ILambdaDeploymentConfig")
@software.amazon.jsii.Jsii.Proxy(ILambdaDeploymentConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ILambdaDeploymentConfig extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.codedeploy.IBaseDeploymentConfig {

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The ARN of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigArn() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * The physical, human-readable name of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigName() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }

    /**
     * Internal default implementation for {@link ILambdaDeploymentConfig}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends ILambdaDeploymentConfig, software.amazon.awscdk.services.codedeploy.IBaseDeploymentConfig.Jsii$Default {

        /**
         * The ARN of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigArn() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * The physical, human-readable name of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigName() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }
}

==> aws-cdk-lib-2.130.0-sources.jar: software/amazon/awscdk/services/codedeploy/ILambdaDeploymentConfig.java <==
package software.amazon.awscdk.services.codedeploy;

/**
 * The Deployment Configuration of a Lambda Deployment Group.
 * <p>
 * If you're managing the Deployment Configuration alongside the rest of your CDK resources,
 * use the <code>LambdaDeploymentConfig</code> class.
 * <p>
 * If you want to reference an already existing deployment configuration,
 * or one defined in a different CDK Stack,
 * use the <code>LambdaDeploymentConfig#fromLambdaDeploymentConfigName</code> method.
 * <p>
 * The default, pre-defined Configurations are available as constants on the <code>LambdaDeploymentConfig</code> class
 * (<code>LambdaDeploymentConfig.AllAtOnce</code>, <code>LambdaDeploymentConfig.Canary10Percent30Minutes</code>, etc.).
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-02-23T02:06:29.760Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_codedeploy.ILambdaDeploymentConfig")
@software.amazon.jsii.Jsii.Proxy(ILambdaDeploymentConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ILambdaDeploymentConfig extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.codedeploy.IBaseDeploymentConfig {

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codedeploy.ILambdaDeploymentConfig.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The ARN of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigArn() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * The physical, human-readable name of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigName() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }

    /**
     * Internal default implementation for {@link ILambdaDeploymentConfig}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends ILambdaDeploymentConfig, software.amazon.awscdk.services.codedeploy.IBaseDeploymentConfig.Jsii$Default {

        /**
         * The ARN of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigArn() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * The physical, human-readable name of the Deployment Configuration.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull java.lang.String getDeploymentConfigName() {
            return software.amazon.jsii.Kernel.get(this, "deploymentConfigName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }
}
